@@ -1,6 +1,9 @@
 import requests
 import json
 import asyncio
+import csv
+import os
+from typing import Optional
 
 
 class Feishu:
@@ -17,8 +20,16 @@ class Feishu:
         "picturetransform服务报警": "https://open.feishu.cn/open-apis/bot/v2/hook/e975aa0a-acef-4e3f-bee4-6dc507b87ebd",
     }
 
-    def __init__(self, channel_name):
+    def __init__(
+        self,
+        channel_name,
+        app_id: Optional[str] = None,
+        app_secret: Optional[str] = None,
+    ):
         self.webhook_url = self.channel_map[channel_name]
+        self.app_id = app_id
+        self.app_secret = app_secret
+        self._access_token = None
 
     def send(self, text):
         print(text)
@@ -132,3 +143,55 @@ class Feishu:
         template: str = "turquoise",
     ):
         return await asyncio.to_thread(self.send_table, headers, rows, title, template)
+
+    def send_file(
+        self,
+        file_url: Optional[str] = None,
+        title: Optional[str] = None,
+        template: str = "turquoise",
+    ):
+        """
+        description:
+            发送文件到飞书群
+            通过文件下载链接发送包含文件下载按钮的卡片消息
+        parameters:
+            file_url(str): 文件下载链接（如 OSS 链接），必需参数
+            title(str): 消息标题，如果为 None 则使用文件名
+            template(str): 卡片模板颜色，默认 "turquoise"
+        return:
+            bool: 发送是否成功
+        """
+        if not file_url:
+            print("错误：必须提供 file_url（文件下载链接）")
+            return False
+        headers = {"Content-Type": "application/json; charset=utf-8"}
+        markdown_content = f"[点击下载文件]({file_url})"
+
+        card = {
+            "config": {"wide_screen_mode": True, "enable_forward": True},
+            "header": {
+                "title": {"tag": "plain_text", "content": title},
+                "template": template,
+            },
+            "elements": [
+                {"tag": "div", "text": {"tag": "lark_md", "content": markdown_content}}
+            ],
+        }
+        payload = {"msg_type": "interactive", "card": card}
+
+        try:
+            resp = requests.post(
+                self.webhook_url, headers=headers, data=json.dumps(payload)
+            )
+            if resp.ok:
+                result = resp.json()
+                return bool(result.get("StatusCode") == 0 or result.get("code") == 0)
+            else:
+                print(f"发送文件消息失败: {resp.status_code}, {resp.text}")
+                return False
+        except Exception as e:
+            print(f"发送文件消息异常: {e}")
+            return False
+
+    async def send_file_async(self, file_url: str, title: str, template: str):
+        return await asyncio.to_thread(self.send_file, file_url, title, template)
